;
; Predeclare I/O and control registers frequently used by COP888EB programmer.
; 09/22/95  Deb Meeker

       .incld cop8.inc
        COPCHIP = COP888EB

        TXD1        =  0A0:BYTE      ; CAN Transmit Data byte 1
        TXD2        =  0A1:BYTE      ; CAN Transmit Data byte 2
        TDLC        =  0A2:BYTE      ; Transmit Data Length Code and ID Low
        TDLC0       =  0             ; Bit 0 transmit data length code
        TDLC1       =  1             ; Bit 1 transmit data length code
        TDLC2       =  2             ; Bit 2 TDLC
        TDLC3       =  3             ; Bit 3 TDLC
        TID0        =  4             ; Bit 0 Transmit Identifier
        TID1        =  5             ; Bit 1 TID
        TID2        =  6             ; Bit 2 TID
        TID3        =  7             ; Bit 3 TID

        TID         =  0A3:BYTE      ; Transmit Identifier High
        TID4        =  0             ;Bit 4 TID
        TID5        =  1             ;Bit 5 TID
        TID6        =  2             ;Bit 6 TID
        TID7        =  3             ;Bit 7 TID
        TID8        =  4             ;Bit 8 TID
        TID9        =  5             ;Bit 9 TID
        TID10       =  6             ;Bit 10 TID
        TRTR        =  7             ;Transmit remote frame

        RXD1        =  0A4:BYTE      ; CAN Receive Data byte 1
        RXD2        =  0A5:BYTE      ; CAN Receive Data byte 2
        RIDL        =  0A6:BYTE      ; Receive Data Length Code
                                     ; and Identifier Low
        RDLC0       =  0             ;Bit 0 receive data length code
        RDLC1       =  1             ;Bit 1 receive data length code
        RDLC2       =  2             ;Bit 2 receive data length code
        RDLC3       =  3             ;Bit 3 receive data length code
        RID0        =  4             ;Bit 0 Receive Identifier
        RID1        =  5             ;Bit 1 Receive Identifier
        RID2        =  6             ;Bit 3 Receive Identifier
        RID3        =  7             ;Bit 4 Receive Identifier

        RID         =  0A7:BYTE      ; Receive Identifier High
        RID4        =  0             ;Bit 4 Receive Identifier
        RID5        =  1             ;Bit 5 Receive Identifier
        RID6        =  2             ;Bit 6 Receive Identifier
        RID7        =  3             ;Bit 7 Receive Identifier
        RID8        =  4             ;Bit 8 Receive Identifier
        RID9        =  5             ;Bit 9 Receive Identifier
        RID10       =  6             ;Bit 10 Receive Identifier

        CSCAL       =  0A8:BYTE      ; CAN Prescaler register
        CKS0        =  0             ; CAN CLK /1
        CKS1        =  1
        CKS2        =  2
        CKS3        =  3
        CKS4        =  4
        CKS5        =  5
        CKS6        =  6
        CKS7        =  7             ; CAN CLK /256


        CTIM        =  0A9:BYTE      ; CAN Bus Timing register
        SJ0         =  0             ;Syncronization Jump Width bit 0
        SJ1         =  1             ;Syncronization Jump Width bit 1
                                     ;SJ1  SJ0   Syncronization Jump Width
                                     ; 0    0    1 tcan
                                     ; 0    1    2 tcan
                                     ; 1    0    3 tcan
                                     ; 1    1    4 tcan
        PS0         =  2             ;Phase Segment 1&2 bit 0
        PS1         =  3             ;Phase Segment 1&2 bit 1
        PS2         =  4             ;Phase Segment 1&2 bit 2
                                     ;PS2 PS1 PS0  Length of Phase Segment
                                     ; 0   0   0   1 tcan
                                     ; 0   0   1   2 tcan, etc. until
                                     ; 1   1   1   8 tcan
        PPS0        =  5             ;Propagation Segment bit 0
        PPS1        =  6             ;Propagation Segment bit 1
        PPS2        =  7             ;Propagation Segment bit 3
                                     ;PPS2 PPS1 PPS0  Length of Prop. Seg.
                                     ; 0    0    0    1 tcan
                                     ; 0    0    1    2 tcan, etc. until
                                     ; 1    1    1    8 tcan


        CBUS        =  0AA:BYTE      ; CAN Bus Control register
        FMOD        =  0             ;Fault Confinement Mode Select
                                     ;0= standard mode (error active after
                                     ;   128*11 recessive bits)
                                     ;1= enhanced mode (128 "good" messages)
                
        RXREF0      =  2             ;1= apply reference voltage to pin RX0
        RXREF1      =  3             ;1= apply reference voltage to pin RX1
        TXEN0       =  4             ;output driver enable bit 0
        TXEN1       =  5             ;output driver enable bit 1
                                     ;TXEN1 TXEN0    Output
                                     ; 0      0      TX0,TX1 tristated
                                     ; 0      1      TX0 enabled
                                     ; 1      0      TX1 enabled
                                     ; 1      1      TX0,TX1 enabled
        RIAF        =  6             ;Receive Identifier Acceptance Filter
                                     ;1= accept all messages regardless of
                                     ;   identifier
                                     ;0= compare bits 4 to 10 of received
                                     ;   identifier with mask bits of RID
                                     ;   register
        CMPTST      =  7


        TCNTL       =  0AB:BYTE      ; Transmit Control/Status register
        TXSS        =  0             ;Transmission Start/Stop 1=start
        RIE         =  1             ;1= Receive Interrupt enable
        TIE         =  2             ;1= Transmit Interrupt enable
        CEIE        =  3             ;1= CAN error interrupt enable
                                     ;   (transmit/ receive error)
        RERR        =  4             ;1= Receive error pending
        TERR        =  5             ;1= Transmit error pending
        NS0         =  6             ;Node Status bit 0
        NS1         =  7             ;Node Status bit 1
                                     ;NS1 NS0  outputs
                                     ; 0   0   error active
                                     ; 0   1   error passive
                                     ; 1   0   bus off
                                     ; 1   1   bus off

        RTSTAT      =  0AC:BYTE      ; Receive/Transmit Status register
                                     ; READ ONLY
        RBF         =  0             ;1= Receive buffer full (receive
                                        ;   interrupt pending)
        RCV         =  1             ;RECEIVE MODE
                                     ;1= DEVICE IS RECEIVING A MESSAGE
                                     ;THAT PASSED ACCEPTANCE FILTERING
        RFV         =  2             ;1= received frame valid
        RORN        =  3             ;1= receiver overrun
        ROLD        =  4             ;1= received overload frame
        RRTR        =  5             ;1= received remote transmission
                                     ;request
        TXPND       =  6             ;1= Transmission pending
        TBE         =  7             ;1= Transmit buffer empty (transmit
                                     ;   interrupt pending)

        TEC         =  0AD:BYTE      ; Transmit Error Counter
        TEC0        =  0
        TEC1        =  1
        TEC2        =  2
        TEC3        =  3
        TEC4        =  4
        TEC5        =  5
        TEC6        =  6
        TEC7        =  7
        REC         =  0AE:BYTE      ; Receive Error Counter
        REC0        =  0
        REC1        =  1
        REC2        =  2
        REC3        =  3
        REC4        =  4
        REC5        =  5
        REC6        =  6
        ROVL        =  7

        PORTMD      =  080:BYTE      ; Port M data
        PORTMC      =  081:BYTE      ; Port M configuration
        PORTMP      =  082:BYTE      ; Port M INPUT pin
;       Alternate function bit definitions on port M
        MISO        =  0             ; SPI
        MOSI        =  1             ; SPI
        SCK         =  2             ; SPI
        SS          =  3             ; SPI
        T2A         =  4             ; Timer T2A output
        T2B         =  5             ; Timer T2B output


        MWKEDG      =   084:BYTE     ; Port M MIWU edge select register
        MWKEN       =   085:BYTE     ; Port M MIWU enable register
        MWKPND      =   086:BYTE     ; Port M MIWU pending register

        PORTND      =   088:BYTE     ; Port N data
        PORTNC      =   089:BYTE     ; Port N configuration
        PORTNP      =   08A:BYTE     ; Port N INPUT pin
        PORTNX      =   08B:BYTE     ; Port N Alternate function Enable
;       Alternate function bit definitions on port N
        ESS0        =   0            ; /ESS 0
        ESS1        =   1            ; /ESS 1
        ESS2        =   2            ; /ESS 2
        ESS3        =   3            ; /ESS 3
        ESS4        =   4            ; /ESS 4
        ESS5        =   5            ; /ESS 5
        ESS6        =   6            ; /ESS 6
        ESS7        =   7            ; /ESS 7

        PORTED      =   090:BYTE     ; Port E data
        PORTEC      =   091:BYTE     ; Port E configuration
        PORTEP      =   092:BYTE     ; Port E INPUT pin

        PORTFD      =   094:BYTE     ; Port F data
        PORTFC      =   095:BYTE     ; Port F configuration
        PORTFP      =   096:BYTE     ; Port F INPUT pin

        LWKEDG      =   0C8:BYTE     ; Port L MIWU edge select register
        LWKEN       =   0C9:BYTE     ; Port L MIWU enable register
        LWKPND      =   0CA:BYTE     ; Port L MIWU pending register

        PORTLD      =   0D0:BYTE     ; Port L data
        PORTLC      =   0D1:BYTE     ; Port L configuration
        PORTLP      =   0D2:BYTE     ; Port L INPUT pin
;       Alternate function bit definitions on port L
        CKX         =   1
        TDX         =   2
        RDX         =   3
;

        PORTGD      =   0D4:BYTE     ; Port G data
        PORTGC      =   0D5:BYTE     ; Port G configuration
        PORTGP      =   0D6:BYTE     ; Port G INPUT pin
;       Alternate function bit definitions on port G
        INT         =   0            ; External Interrupt input
        INTR        =   0            ; External Interrupt input
        T1B         =   2            ; Timer T1B output
        T1A         =   3            ; Timer T1A output
        SO          =   4            ; Serial output
        SK          =   5            ; Serial clock
        SI          =   6            ; Serial input

        PORTCD      =   0D8:BYTE     ; Port C data
        PORTCC      =   0D9:BYTE     ; Port C configuration
        PORTCP      =   0DA:BYTE     ; Port C INPUT pin

        PORTI       =   0D7:BYTE     ; Port I INPUT ONLY
;       Alternate function bit definitions on port I
        ACH0        =   0            ; A/D-Channel 0
        ACH1        =   1            ; A/D-Channel 1
        ACH2        =   2            ; A/D-Channel 2
        ACH3        =   3            ; A/D-Channel 3
        ACH4        =   4            ; A/D-Channel 4
        ACH5        =   5            ; A/D-Channel 5
        ACH6        =   6            ; A/D-Channel 6
        ACH7        =   7            ; A/D-Channel 7

        PORTD       =   0DC:BYTE     ; Port D 

        ICNTRL      =   0E8:BYTE     ; ICNTRL register
        T1ENB       =   0            ; Timer T1B interr. enable
        T1PNDB      =   1            ; Timer T1B interr. pending flag
        WEN         =   2            ; Microwire interr. enable
        UWEN        =   WEN
        WPND        =   3            ; Microwire interr. pending
        UWPND       =   WPND
        T0EN        =   4            ; Timer T0 interr. enable
        PPEN        =   T0EN
        T0PND       =   5            ; Timer T0 interr. pending
        PPND        =   T0PND
        LPEN        =   6            ; L-Port interr. enable
        FLAG2       =   LPEN
        FLAG1       =   7

        SIOR        =   0E9:BYTE     ; SIO shift register
        SIO         =   0E9:BYTE     ; SIO shift register
        S           =   0FF          ; Segment register, only COP888CG/CS!
;
        T1RBLO      =   0E6:BYTE     ; Timer 1 RB register low byte
        T1RBHI      =   0E7:BYTE     ; Timer 1 RB register high byte
        TMR1LO      =   0EA:BYTE     ; Timer 1 low byte
        TMR1HI      =   0EB:BYTE     ; Timer 1 high byte
        T1RALO      =   0EC:BYTE     ; Timer 1 RA register low byte
        T1RAHI      =   0ED:BYTE     ; Timer 1 RA register high byte

;

        TMR2LO      =   0C0:BYTE     ; Timer 2 low byte
        TMR2HI      =   0C1:BYTE     ; Timer 2 high byte
        T2RALO      =   0C2:BYTE     ; Timer 2 RA register low byte
        T2RAHI      =   0C3:BYTE     ; Timer 2 RA register high byte
        T2RBLO      =   0C4:BYTE     ; Timer 2 RB register low byte
        T2RBHI      =   0C5:BYTE     ; Timer 2 RB register high byte
        T2CNTRL     =   0C6:BYTE     ; Timer 2 control register
;       Bit definitions T2CNTRL register
        T2C3        =   7            ; Timer T2 mode control
        T2C2        =   6            ; Timer T2 mode control
        T2C1        =   5            ; Timer T2 mode control
        T2C0        =   4            ; Timer T2A start/stop
        T2PNDA      =   3            ; Timer T2A interr. pending flag
        T2ENA       =   2            ; Timer T2A interr. enable
        T2PNDB      =   1            ; Timer T2B interr. pending flag
        T2ENB       =   0            ; Timer T2B interr. enable
;
        CNTRL       =   0EE:BYTE     ; Control register
        S0          =   0            ; Microwire clock divide select
        SL0         =   0
        S1          =   1            ; Microwire clock divide select
        SL1         =   1
        IEDG        =   2            ; Selects external interr. edge polarity
        MSEL        =   3            ; Enable Microwire
        T1C0        =   4            ; Start/Stop timer in modes 1 and 2
                                     ; Underflow interrupt pending in mode 3
        TRUN        =   T1C0         ; COP880/840/820 control signal name
        T1C1        =   5            ; Timer 1 mode control
        TC3         =   T1C1         ; COP880/840/820 control signal name
        T1C2        =   6            ; Timer 1 mode control
        TC2         =   T1C2         ; COP880/840/820 control signal name
        T1C3        =   7            ; Timer 1 mode control
        TC1         =   T1C3         ; COP880/840/820 control signal name

        PSW         =   0EF:BYTE     ; PSW register
        GIE         =   0            ; Global interr. enable
        ENI         =   1            ; External interr. enable
        EXEN        =   ENI
        BUSY        =   2            ; Microwire busy shifting
        IPND        =   3            ; External interr. pending
        EXPND       =   IPND
        ENTI        =   4            ; Timer interr. enable
        T1ENA       =   ENTI
        TPND        =   5            ; Timer interr. pending
        T1PNDA      =   TPND
        C           =   6            ; Carry flag
        HC          =   7            ; Half carry flag
;
        SPICNTL     =   098:BYTE     ; SPI Control Register
        SLOOP       =   0            ;SPI LOOP BACK
        SPIEN       =   1            ;SPI ENABLE
        SCE         =   2            ;SPI ACTIVE CLOCK EDGE SELECT
                                     ; 0 = data shifted out on falling edge
                                     ; 1 = data shifted out on risinge edge
        SPIMOD0     =   3            ;SPI OPERATION MODE CONTROL
        SPIMOD1     =   4            ; 0,0 = Slave mode
                                     ; 1,0 = Std master mode
        SESSEN      =   5            ;SPI /SS EXPANDER (ESS) ENABLE
        STIE        =   6            ;SPI TRANSMIT BUFFER INTERRUPT ENABLE
        SRIE        =   7            ;SPI RECEIVE INTERRUPT ENABLE
                
        SPISTAT     =   099:BYTE     ; SPI Status Register
        RFLUSH      =   1            ;RECEIVE FIFO FLUSH
        SESSDET     =   2            ;SPI SS EXPANDER DETECTION
        STFL        =   3            ;SPI TRANSMIT BUFFER FLUSH
        STBE        =   4            ;SPI TRANSMIT BUFFER EMPTY
        STBF        =   5            ;SPI TRANSMIT BUFFER FULL
        SRBNE       =   6            ;SPI RECEIVER BUFFER NOT EMPTY
        SRORN       =   7            ;SPI RECEIVER OVERRUN

        SPIRXD      =   09A:BYTE     ; SPI Current receive data (read only)
        SPITXD      =   09B:BYTE     ; SPI Transmit data

;
        TBUF        =   0B8          ; UART transmit buffer
        RBUF        =   0B9          ; UART receive buffer
        ENU         =   0BA          ; UART control and status register
;       Bit definitions ENU register
        PEN         =   7            ; Parity enable
        PSEL1       =   6            ; Parity select
        PSEL0       =   5            ; Parity select
        XBIT9       =   5            ; 9th transmission bit in 9bit data mode
        CHL1        =   4            ; Select character frame format
        CHLO        =   3            ; Select character frame format
        ERR         =   2            ; Error flag
        RBFL        =   1            ; Received character
        TBMT        =   0            ; Transmited character
;
        ENUR        =   0BB          ; UART receive control and status reg.
;               Bit definitions ENUR register
        DOE         =   7            ; Data overrun error
        FE          =   6            ; Framing error
        PE          =   5            ; Parity error
        RBIT9       =   3            ; Contains the ninth bit (nine bit frame!)
        ATTN        =   2            ; Attention mode
        XMTG        =   1            ; indicate transmitting mode
        RCVG        =   0            ; indicate framing error
;
        ENUI        =   0BC          ; UART interrupt and clock source reg.
;       Bit definition ENUI register
        STP2        =   7            ; Select number of stop bits
        STP78       =   6            ; Select the last stop bit
        ETDX        =   5            ; Select transmit-pin l2
        SSEL        =   4            ; Select UART-mode
        XRCLK       =   3            ; Select clock source for the receiver
        XTCLK       =   2            ; Select clock source for the transmitter
        ERI         =   1            ; Enable interr. from the receiver
        ETI         =   0            ; enable interr. from the transmitter
;
        BAUD        =   0BD          ; BAUD register
        PSR         =   0BE          ; UART prescaler select register
;
        ENAD        =   0CB:BYTE     ; A/D Convertor Control Register
;       Bit definitions ENAD register
        ADCH2       =   7            ; A/D Convertor Channel Select bit 2
        ADCH1       =   6            ; A/D Convertor Channel Select bit 1
        ADCH0       =   5            ; A/D Convertor Channel Select bit 0
        ADMOD1      =   4            ; A/D Convertor Mode Select bit 1
        ADMOD0      =   3            ; A/D Convertor Mode Select bit 0
        PSC1        =   2            ; A/D Convertor Prescale Select bit 1
        PSC0        =   1            ; A/D Convertor Prescale Select bit 0
        ADBSY       =   0            ; A/D Convertor Busy Bit
;

        ADRSLT      =   0CC:BYTE     ; A/D Convertor Result Register
        ITMR        =   0CF:BYTE     ; Selectable IDLE Timer Control Register
;       Bit Definitions for ITMR Register
        ITSTMD      =   3            ; IDLE Timer Test Bist Mode
        ITSEL2      =   2            ; IDLE Timer Period Select bit 2
        ITSEL1      =   1            ; IDLE Timer Period Select bit 1
        ITSEL0      =   0            ; IDLE Timer Period Select bit 0
;                                   
        WDSVR       =   0C7:BYTE     ; Watch dog service register


       .CHIP 888EB                   ; specifies max. ROM address 1FFF
