;
; Predeclare I/O and control registers frequently used by COP888FH programmer.
;
       .incld cop8.inc
        COPCHIP = COP888FH

        PORTLD      =   0xD0         ; Port L data
        PORTLC      =   0xD1         ; Port L configuration
        PORTLP      =   0xD2         ; Port L pin
;
        PORTCD      =   0xD8         ; Port C data
        PORTCC      =   0xD9         ; Port C configuration
        PORTCP      =   0xDA         ; Port C pin
;
        PORTGD      =   0xD4         ; Port G data
        PORTGC      =   0xD5         ; Port G configuration
        PORTGP      =   0xD6         ; Port G pin
;
        PORTD       =   0xDC         ; Port D
        PORTI       =   0xD7         ; Port I
;
        SIOR        =   0xE9         ; SIO shift register
        SIO         =   0xE9         ; SIO shift register
        S           =   0xFF         ; Segment register, only COP888CG/CS!

        TMR1LO      =   0xEA         ; Timer 1 low byte
        TMR1HI      =   0xEB         ; Timer 1 high byte
        T1RALO      =   0xEC         ; Timer 1 RA register low byte
        T1RAHI      =   0xED         ; Timer 1 RA register high byte
        T1RBLO      =   0xE6         ; Timer 1 RB register low byte
        T1RBHI      =   0xE7         ; Timer 1 RB register high byte
;
        TMR2LO      =   0xC0         ; Timer 2 low byte
        TMR2HI      =   0xC1         ; Timer 2 high byte
        T2RALO      =   0xC2         ; Timer 2 RA register low byte
        T2RAHI      =   0xC3         ; Timer 2 RA register high byte
        T2RBLO      =   0xC4         ; Timer 2 RB register low byte
        T2RBHI      =   0xC5         ; Timer 2 RB register high byte
        T2CNTRL     =   0xC6         ; Timer 2 control register
;
        TMR3LO      =   0xB0         ; Timer 3 low byte
        TMR3HI      =   0xB1         ; Timer 3 high byte
        T3RALO      =   0xB2         ; Timer 3 RA register low byte
        T3RAHI      =   0xB3         ; Timer 3 RA register high byte
        T3RBLO      =   0xB4         ; Timer 3 RB register low byte
        T3RBHI      =   0xB5         ; Timer 3 RB register high byte
        T3CNTRL     =   0xB6         ; Timer 3 control register
;
        CNTRL       =   0xEE         ; control register
        PSW         =   0xEF         ; PSW register
        WDSVR       =   0xC7         ; Watch dog service register
        WKEDG       =   0xC8         ; MIWU edge select register
        WKEN        =   0xC9         ; MIWU enable register
        WKPND       =   0xCA         ; MIWU pending register
        ICNTRL      =   0xE8         ; Interrupt control register
;
        CMPSL       =   0xB7         ; Comparator select register
        TBUF        =   0xB8         ; UART transmit buffer
        RBUF        =   0xB9         ; UART receive buffer
        ENU         =   0xBA         ; UART control and status register
        ENUR        =   0xBB         ; UART receive control and status reg.
        ENUI        =   0xBC         ; UART interrupt and clock source reg.
        BAUD        =   0xBD         ; BAUD register
        PSR         =   0xBE         ; UART prescaler select register
;
        MDR1        =   098          ; Multiplication unused
                                     ; Division before low byte dividend
                                     ; after low byte result
        MDR2        =   099          ; Multiplication before multilier
                                     ; after low byte of result
                                     ; Division before middle byte of dividend
                                     ; after high byte of result
        MDR3        =   09A          ; Multiplication before unused
                                     ; after middle byte of result
                                     ; Division before high byte of dividend
                                     ; after undefined
        MDR4        =   09B          ; Multiplication before low byte of multipcand
                                     ; After high byte of result
                                     ; Division before low byte of divisor
                                     ; after low byte of divisor
        MDR5        =   09C          ; Multiplication before high byte of mutltiplicand
                                     ; after unchanged
                                     ; Division before high byte of divisor
                                     ; after high byte of divisor
        MDCR        =   09D          ; Multiply Divide control register
;
; CONSTANT DECLARE
;       Alternate function bit definitions on port G
        INT         =   0            ; Interrupt input
        INTR        =   0            ; Interrupt input
        WDOUT       =   1            ; Watchdog output
        T1B         =   2            ; Timer T1B output
        T1A         =   3            ; Timer T1A output
        SO          =   4            ; Serial output
        SK          =   5            ; Serial clock
        SI          =   6            ; Serial input
        CKO         =   7            ; Halt,restart input
;
;       Alternate function bit definitions on port L
        CKX         =   1            ; ext. clock I/O-pin/UART
        TDX         =   2            ; transmit data/UART
        RDX         =   3            ; receive data/UART
        T2A         =   4            ; Timer T2A output
        T2B         =   5            ; Timer T2B output
        T3A         =   6            ; Timer T3A output
        T3B         =   7            ; Timer T3B output
;
;       Alternate function bit definitions on port I
        CMP1INN     =   1            ; Comparator 1 negative input
        CMP1INP     =   2            ; Comparator 1 positive input
        CMP1OUT     =   3            ; Comparator 1 output
        CMP2INN     =   4            ; Comparator 2 negative input
        CMP2INP     =   5            ; Comparator 2 positive input
        CMP2OUT     =   6            ; Comparator 2 output


;       Bit definitions CNTRL register
        T1C3        =   7            ; Timer 1 mode control
        TC1         =   T1C3         ; COP880/840/820 control signal name
        T1C2        =   6            ; Timer 1 mode control
        TC2         =   T1C2         ; COP880/840/820 control signal name
        T1C1        =   5            ; Timer 1 mode control
        TC3         =   T1C1         ; COP880/840/820 control signal name
        T1C0        =   4            ; Start/Stop timer in modes 1 and 2
                                     ; Underflow interrupt pending in mode 3
        TRUN        =   T1C0         ; COP880/840/820 control signal name
        MSEL        =   3            ; Enable Microwire
        IEDG        =   2            ; Selects external interr. edge polarity
        S1          =   1            ; Microwire clock divide select
        SL1         =   S1
        S0          =   0            ; Microwire clock divide select
        SL0         =   S0
;
;       Bit definitions PSW register
        HC          =   7            ; Half carry flag
        C           =   6            ; Carry flag
        TPND        =   5            ; Timer interr. pending
        ENTI        =   4            ; Timer interr. enable
        IPND        =   3            ; External interr. pending
        BUSY        =   2            ; Microwire busy shifting
        ENI         =   1            ; External interr. enable
        GIE         =   0            ; Global interr. enable
;
;       Bit definitions ICNTRL register
        LPEN        =   6            ; L-Port interr. enable
        T0PND       =   5            ; Timer T0 interr. pending
        T0EN        =   4            ; Timer T0 interr. enable
        WPND        =   3            ; Microwire interr. pending
        WEN         =   2            ; Microwire interr. enable
        T1PNDB      =   1            ; Timer T1B interr. pending flag
        T1ENB       =   0            ; Timer T1B interr. enable
;
;       Bit definitions T2CNTRL register
        T2C3        =   7            ; Timer T2 mode control
        T2C2        =   6            ; Timer T2 mode control
        T2C1        =   5            ; Timer T2 mode control
        T2C0        =   4            ; Timer T2A start/stop
        T2CO        =   4            ; Timer T2A start/stop
        T2PNDA      =   3            ; Timer T2A interr. pending flag
        T2ENA       =   2            ; Timer T2A interr. enable
        T2PNDB      =   1            ; Timer T2B interr. pending flag
        T2ENB       =   0            ; Timer T2B interr. enable
;
;       Bit definitions T3CNTRL register
        T3C3        =   7            ; Timer T3 mode control
        T3C2        =   6            ; Timer T3 mode control
        T3C1        =   5            ; Timer T3 mode control
        T3C0        =   4            ; Timer T3A start/stop
        T3CO        =   4            ; Timer T3A start/stop
        T3PNDA      =   3            ; Timer T3A interr. pending flag
        T3ENA       =   2            ; Timer T3A interr. enable
        T3PNDB      =   1            ; Timer T3B interr. pending flag
        T3ENB       =   0            ; Timer T3B interr. enable
;
;       Bit definitions CMPSL register
        CMP2OE      =   6            ; Select COMP2OUT as output
        CMP2RD      =   5            ; Comparator 2 result (read only)
        CMP2EN      =   4            ; Comparator 2 enable
        CMP1OE      =   3            ; Select COMP1OUT as output
        CMP1RD      =   2            ; Comparator result (read only)
        CMP1EN      =   1            ; Comparator 1 enable
;
;       Bit definitions ENU register
        PEN         =   7            ; Parity enable
        PSEL1       =   6            ; Parity select
        PSEL0       =   5            ; Parity select
        XBIT9       =   5            ; 9th transmission bit in 9bit data mode
        CHL1        =   4            ; Select character frame format
        CHL0        =   3            ; Select character frame format
        ERR         =   2            ; Error flag
        RBFL        =   1            ; Received character
        TBMT        =   0            ; Transmited character
;
;       Bit definitions ENUR register
        DOE         =   7            ; Data overrun error
        FE          =   6            ; Framing error
        PE          =   5            ; Parity error
        RBIT9       =   3            ; Contains the ninth bit (nine bit frame!)
        ATTN        =   2            ; Attention mode
        XMTG        =   1            ; indicate transmitting mode
        RCVG        =   0            ; indicate framing error
;
;       Bit definition ENUI register
        STP2        =   7            ; Select number of stop bits
        STP78       =   6            ; Select the last stop bit
        ETDX        =   5            ; Select transmit-pin l2
        SSEL        =   4            ; Select UART-mode
        XRCLK       =   3            ; Select clock source for the receiver
        XTCLK       =   2            ; Select clock source for the transmitter
        ERI         =   1            ; Enable interr. from the receiver
        ETI         =   0            ; enable interr. from the transmitter
;
;       Bit definition MDCR register
        MULT        =   0            ; Start Multiplication 1 = start
        DIV         =   1            ; Start Division  1 = start
        DIVOVF      =   2            ; Division overflow 1 = error

;
        .CHIP 888FH                  ; specifies max. ROM address 2FFF
