;
; Predeclare I/O and control registers frequently used by COP8ACC programmer.
;
        .INCLD  COP8.INC
        COPCHIP = COP8ACC

;  ***  Comparator Select Register ***

        CMPSL       =   0B7:BYTE     ; Comparator select register

;  ***  Watch - Dog Service Register  ***

        WDSVR       =   0C7:BYTE     ; Watch dog service register

;  *** MicroWire Control Registers  *** 

        WKEDG       =   0C8:BYTE     ; MIWU edge select register
        WKEN        =   0C9:BYTE     ; MIWU enable register
        WKPND       =   0CA:BYTE     ; MIWU pending register

;  ***  Capture Timer and Capture Timer Control Registers  ***

        CAPTLO      =   0CC:BYTE     ; Campture Timer Lo
        CAPTHI      =   0CD:BYTE     ; Capture Timer Hi
        CAPCNTL     =   0CE:BYTE     ; capture Timer Control

;  ***  Idle Timer Control Register  ***

        ITMR        =   0CF:BYTE     ; Idle Timer Control Reg.

;  ***  Input/Output Port-,Data- and Configuration Registers  ***

        PORTLD      =   0D0:BYTE     ; Port L data
        PORTLC      =   0D1:BYTE     ; Port L configuration
        PORTLP      =   0D2:BYTE     ; Port L pin
;
        PORTGD      =   0D4:BYTE     ; Port G data
        PORTGC      =   0D5:BYTE     ; Port G configuration
        PORTGP      =   0D6:BYTE     ; Port G pin (read only inputs)
;
        PORTI       =   0D7:BYTE     ; Port I (read only inputs)
;
        PORTD       =   0DC:BYTE     ; Port D

;  ***  Serial I/O Shift Register  ***

        SIOR        =   0E9:BYTE     ; SIO shift register
        SIO         =   0E9:BYTE     ; SIO shift register

;  *** Timer 1 and Timer 1 Autoreload Registers

        TMR1LO      =   0EA:BYTE     ; Timer 1 low byte
        TMR1HI      =   0EB:BYTE     ; Timer 1 high byte
        T1RALO      =   0EC:BYTE     ; Timer 1 RA register low byte
        T1RAHI      =   0ED:BYTE     ; Timer 1 RA register high byte
        T1RBLO      =   0E6:BYTE     ; Timer 1 RB register low byte
        T1RBHI      =   0E7:BYTE     ; Timer 1 RB register high byte
;
;  *** Control Registers  ***

        CNTRL       =   0EE:BYTE     ; control register
        PSW         =   0EF:BYTE     ; PSW register

        ICNTRL      =   0E8:BYTE     ; Interrupt control register

;
; CONSTANT DECLARE
;
;  ***  Alternate function bit definitions on port G  ***

        INT         =   0            ; Interrupt input
        INTR        =   0            ; Interrupt input
        WDOUT       =   1            ; Watchdog output
        T1B         =   2            ; Timer T1B output
        T1A         =   3            ; Timer T1A output
        SO          =   4            ; Serial output
        SK          =   5            ; Serial clock
        SI          =   6            ; Serial input
        CKO         =   7            ; Halt,restart input
;
;  ***  Alternate function bit definitions on port I  ***
;
        Ach1        =   0            ; Analog Channel 1
        Isrc        =   1            ; Output from current Source
        Ach2        =   2            ; Analog Channel 2
        Ach3        =   3            ; Analog Channel 3 (Comp.-Out)
        Ach4        =   4            ; Analog Channel 4
        Ach5        =   5            ; Analog Channel 5
        Ach6        =   6            ; Analog Channel 6
        Cout        =   7            ; Comparator output
;
;  ***  Bit definitions CNTRL register  ***
;
        T1C3        =   7            ; Timer 1 mode control
        TC1         =   T1C3         ; COP880/840/820 control signal name
        T1C2        =   6            ; Timer 1 mode control
        TC2         =   T1C2         ; COP880/840/820 control signal name
        T1C1        =   5            ; Timer 1 mode control
        TC3         =   T1C1         ; COP880/840/820 control signal name
        T1C0        =   4            ; Start/Stop timer in modes 1 and 2
                                     ; Underflow interrupt pending in mode 3
        TRUN        =   T1C0         ; COP880/840/820 control signal name
        MSEL        =   3            ; Enable Microwire
        IEDG        =   2            ; Selects external interr. edge polarity
        S1          =   1            ; Microwire clock divide select
        S0          =   0            ; Microwire clock divide select
        SL1         =   1            ; Microwire clock divide select
        SL0         =   0            ; Microwire clock divide select
;
;  ***  Bit definitions PSW register   ***
;
        HC          =   7            ; Half carry flag
        C           =   6            ; Carry flag
        TPND        =   5            ; Timer interr. pending
        T1PNDA      =   TPND         ; Timer Interr. pending
        ENTI        =   4            ; Timer interr. enable
        T1ENA       =   ENTI         ; Timer interr. enable
        IPND        =   3            ; External interr. pending
        EXPND       =   IPND         ; External interr. pending
        BUSY        =   2            ; Microwire busy shifting
        ENI         =   1            ; External interr. enable
        EXEN        =   ENI          ; External interr. enable
        GIE         =   0            ; Global interr. enable
;
;  ***  Bit definitions ICNTRL register   ***
;
        LPEN        =   6            ; L-Port interr. enable
        T0PND       =   5            ; Timer T0 interr. pending
        PPND        =   T0PND        ; Used for T0PND, Idle Interrupt Pending
        T0EN        =   4            ; Timer T0 interr. enable
        PEN         =   T0EN         ; Used for T0EN, Idle Interrupt Pending
        WPND        =   3            ; Microwire interr. pending
        uWPND       =   WPND         ; Microwire interr. pending
        WEN         =   2            ; Microwire interr. enable
        uWEN        =   WEN          ; Microwire interr. enable
        T1PNDB      =   1            ; Timer T1B interr. pending flag
        T1ENB       =   0            ; Timer T1B interr. enable
;
;  ***  Bit definitions CMPSL register   ***
;
        CMPT2B      =   7            ; COMPARATOR TO Capture Timer
        CMPISEL2    =   6            ; INPUT SELECT 2
        CMPISEL1    =   5            ; INPUT SELECT 1
        CMPISEL0    =   4            ; INPUT SELECT 0
        CMPOE       =   3            ; COMPARATOR OUTPUT ENABLE
        CSEN        =   2            ; CURRENT SOURCE ENABLE
        CMPEN       =   1            ; Comparator enable
        CMPNEG      =   0            ; COMPARATOR DISCHARGE FOR CAP
;
;  ***  Bit definitions CAPCNTL register   ***
;
        CAPIEN      =   0            ; Capture interrupts enable
        CAPPND      =   1            ; Capture pending
        CAPOVL      =   2            ; Capture timer overflow
        CAPRUN      =   3            ; Capture timer run
        CAPMOD      =   4            ; Capture timer reset
        CTMOD       =   7            ; capture test mode
;
;  ***  Special Control Bits for HALT and Alternate SK ShifT  ***
;
        HALT        =   7            ; Bit 7 of G-PORT Data-Register
        SKSEL       =   6            ; Bit 6 of G-PORT Configuration
                                     ; Register

;
;
        .CHIP 8ACC                   ; specifies max. ROM address 0FFF
