; This is cop8S3R.inc
;
; PLEASE: Consider update for SBR, SDR, SCR, SBE, SDE and SCE.
;
; Predeclare I/O and control registers frequently used by COP8 programmer.
        .macro  setopt
        .mloc   sec,wd,halt,flex
;
        .ifb    @1      ; if null
sec     =       0       ; default value (not secure)
        .else
sec     =       @1
        .endif
        .ifb    @2      ; if null
wd      =       0       ; default value (Watchdog enabled)
        .else
wd      =       @2
        .endif
        .ifb    @3      ; if null
halt    =       0       ; default value (HALT enabled)
        .else
halt    =       @3
        .endif
        .ifb    @4      ; if null
flex    =       1       ; default value (Execute from Flash)
        .else
flex    =       @4
        .endif

        .sect   OPTION, CONF
CONFIG: .db     ((sec shl 3 or wd) shl 1 or halt) shl 1 or flex
        .endm

; ----------------- End of setecon Macro Definition ---------------------
;
; -----------------------------------------------------------------------
; SFR Names and Register Bit Names Agree with the Feature Family User's
; Manual Redundant names match corresponding functions on Basic Family
; Documentation
;

        PORTED      =   0x90:BYTE    ; Port E Data
        PORTEC      =   0x91:BYTE    ; Port E Configuration
        PORTEP      =   0x92:BYTE    ; Port E input pins (read only)
;
        PORTFD      =   0x94:BYTE    ; Port F Data
        PORTFC      =   0x95:BYTE    ; Port F Configuration
        PORTFP      =   0x96:BYTE    ; Port F input pins (read only)
;
        PORTAD      =   0xA0:BYTE    ; Port A Data
        PORTAC      =   0xA1:BYTE    ; Port A Configuration
        PORTAP      =   0xA2:BYTE    ; Port A input pins (read only)
;
        PORTBD      =   0xA4:BYTE    ; Port B Data
        PORTBC      =   0xA5:BYTE    ; Port B Configuration
        PORTBP      =   0xA6:BYTE    ; Port B input pins (read only)
;
        ISPADLO     =   0xA8:BYTE    ; ISP Address Register Low Byte
        ISPADHI     =   0xA9:BYTE    ; ISP Address Register High Byte
        ISPRD       =   0xAA:BYTE    ; ISP Read Data Register
        ISPWR       =   0xAB:BYTE    ; ISP Write Data Register
;
        TINTA       =   0xAD:BYTE    ; High Speed Timers Interrupt A
        TINTB       =   0xAE:BYTE    ; High Speed Timers Interrupt B
        HSTCR       =   0xAF:BYTE    ; High Speed Timers Control Register
;
.if _timers = 3
        TMR3LO      =   0xB0:BYTE    ; Timer 3 low byte
        TMR3HI      =   0xB1:BYTE    ; Timer 3 high byte
        T3RALO      =   0xB2:BYTE    ; Timer 3 RA register low byte
        T3RAHI      =   0xB3:BYTE    ; Timer 3 RA register high byte
        T3RBLO      =   0xB4:BYTE    ; Timer 3 RB register low byte
        T3RBHI      =   0xB5:BYTE    ; Timer 3 RB register high byte
        T3CNTRL     =   0xB6:BYTE    ; Timer 3 control register
.endif
;
        TBUF        =   0xB8:BYTE    ; UART transmit buffer
        RBUF        =   0xB9:BYTE    ; UART receive buffer
        ENU         =   0xBA:BYTE    ; UART control and status register
        ENUR        =   0xBB:BYTE    ; UART receive control and status reg.
        ENUI        =   0xBC:BYTE    ; UART interrupt and clock source reg.
        BAUD        =   0xBD:BYTE    ; BAUD register
        PSR         =   0xBE:BYTE    ; UART prescaler select register
;
.if _timers >= 2
        TMR2LO      =   0xC0:BYTE    ; Timer 2 low byte
        TMR2HI      =   0xC1:BYTE    ; Timer 2 high byte
        T2RALO      =   0xC2:BYTE    ; Timer 2 RA register low byte
        T2RAHI      =   0xC3:BYTE    ; Timer 2 RA register high byte
        T2RBLO      =   0xC4:BYTE    ; Timer 2 RB register low byte
        T2RBHI      =   0xC5:BYTE    ; Timer 2 RB register high byte
        T2CNTRL     =   0xC6:BYTE    ; Timer 2 control register
.endif
;
        WDSVR       =   0xC7:BYTE    ; Watch dog service register
;
        WKEDG       =   0xC8:BYTE    ; MIWU edge select register
        WKEN        =   0xC9:BYTE    ; MIWU enable register
        WKPND       =   0xCA:BYTE    ; MIWU pending register
;
        ITMR        =   0xCF:BYTE    ; Idle Timer Control Register
;
        PORTLD      =   0xD0:BYTE    ; Port L data
        PORTLC      =   0xD1:BYTE    ; Port L configuration
        PORTLP      =   0xD2:BYTE    ; Port L pin
;
        PORTGD      =   0xD4:BYTE    ; Port G data
        PORTGC      =   0xD5:BYTE    ; Port G configuration
        PORTGP      =   0xD6:BYTE    ; Port G pin
;
        PORTCD      =   0xD8:BYTE    ; Port C data
        PORTCC      =   0xD9:BYTE    ; Port C configuration
        PORTCP      =   0xDA:BYTE    ; Port C pin
;
.ifndef _hport
        PORTD       =   0xDC:BYTE    ; Port D
;
.else
        PORTHD      =   0xDC:BYTE    ; Port H data
        PORTHC      =   0xDD:BYTE    ; Port H configuration
        PORTHP      =   0xDE:BYTE    ; Port H pin
.endif
;
        PGMTIM      =   0xE1:BYTE    ; E2 and Flash Write Timing Register
        ISPKEY      =   0xE2:BYTE    ; ISP Key Register
;
        T1RBLO      =   0xE6:BYTE    ; Timer 1 RB register low byte
        T1RBHI      =   0xE7:BYTE    ; Timer 1 RB register high byte
;
        ICNTRL      =   0xE8:BYTE    ; Interrupt control register
;
        SIOR        =   0xE9:BYTE    ; SIO shift register
        SIO         =   0xE9:BYTE    ; SIO shift register
;
        TMR1LO      =   0xEA:BYTE    ; Timer 1 low byte
        TMR1HI      =   0xEB:BYTE    ; Timer 1 high byte
        T1RALO      =   0xEC:BYTE    ; Timer 1 RA register low byte
        T1RAHI      =   0xED:BYTE    ; Timer 1 RA register high byte
;
        CNTRL       =   0xEE:BYTE    ; control register
        PSW         =   0xEF:BYTE    ; PSW register
;
        BYTECOUNTLO =   0xF1:BYTE    ; When JSRB Boot Rom used
;
        S           =   0xFF:BYTE    ; Segment register, only COP888CG/CS!
;

;------------------------------------------------------------------------
; Bit Constant Declarations.
;
;----- Alternate function bit definitions on port G

        INT         =   0            ; Interrupt input
        INTR        =   0            ; Interrupt input
        WDOUT       =   1            ; Watchdog output
        T1B         =   2            ; Timer T1B output
        T1A         =   3            ; Timer T1A output
        SO          =   4            ; Seriell output
        SK          =   5            ; Seriell clock
        SI          =   6            ; Seriell input
        CKO         =   7            ; Halt,restart input
;
;----- Alternate function bit definitions on port L
        CKX         =   1            ; ext. clock I/O-pin/UART
        TDX         =   2            ; transmit data/UART
        RDX         =   3            ; receive data/UART
.if _timers >= 2
        T2A         =   4            ; Timer T2A output
        T2B         =   5            ; Timer T2B output
.endif
.if _timers = 3
        T3A         =   6            ; Timer T3A output
        T3B         =   7            ; Timer T3B output
.endif
;
;----- Bit definitions CNTRL register
        T1C3        =   7            ; Timer 1 mode control
        TC1         =   T1C3         ; COP880/840/820 control signal name
        T1C2        =   6            ; Timer 1 mode control
        TC2         =   T1C2         ; COP880/840/820 control signal name
        T1C1        =   5            ; Timer 1 mode control
        TC3         =   T1C1         ; COP880/840/820 control signal name
        T1C0        =   4            ; Start/Stop timer in modes 1 and 2
                                     ; Underflow interrupt pending in mode 3
        TRUN        =   T1C0         ; COP880/840/820 control signal name
        MSEL        =   3            ; Enable Microwire
        IEDG        =   2            ; Selects external interr. edge polarity
        SL1         =   1            ; Microwire clock divide select
        SL0         =   0            ; Microwire clock divide select
;
;----- Bit definitions PSW register
        HC          =   7            ; Half Historical Redundant carry flag
        C           =   6            ; Carry flag
        T1PNDA      =   5            ; Timer T1A interrupt pending
        TPND        =   T1PNDA       ; Historical Redundant
        T1ENA       =   4            ; Timer T1A interrupt enable
        ENTI        =   T1ENA        ; Historical Redundant
        EXPND       =   3            ; External interrupt pending
        IPND        =   EXPND        ; Historical Redundant
        BUSY        =   2            ; Microwire busy shifting
        EXEN        =   1            ; External interurpt enable
        ENI         =   EXEN         ; Historical Redundant
        GIE         =   0            ; Global interr. enable
;
;----- Bit definitions ICNTRL register
        LPEN        =   6            ; L-Port interr. enable
        T0PND       =   5            ; Timer T0 interr. pending
        T0EN        =   4            ; Timer T0 interr. enable
        WPND        =   3            ; Microwire interr. pending
        WEN         =   2            ; Microwire interr. enable
        T1PNDB      =   1            ; Timer T1B interr. pending flag
        T1ENB       =   0            ; Timer T1B interr. enable
;
.if _timers >= 2
;----- Bit definitions T2CNTRL register
        T2C3        =   7            ; Timer T2 mode control
        T2C2        =   6            ; Timer T2 mode control
        T2C1        =   5            ; Timer T2 mode control
        T2C0        =   4            ; Timer T2A start/stop
        T2PNDA      =   3            ; Timer T2A interr. pending flag
        T2ENA       =   2            ; Timer T2A interr. enable
        T2PNDB      =   1            ; Timer T2B interr. pending flag
        T2ENB       =   0            ; Timer T2B interr. enable
;
.endif
.if _timers = 3
;----- Bit definitions T3CNTRL register
        T3C3        =   7            ; Timer T3 mode control
        T3C2        =   6            ; Timer T3 mode control
        T3C1        =   5            ; Timer T3 mode control
        T3C0        =   4            ; Timer T3A start/stop
        T3PNDA      =   3            ; Timer T3A interr. pending flag
        T3ENA       =   2            ; Timer T3A interr. enable
        T3PNDB      =   1            ; Timer T3B interr. pending flag
        T3ENB       =   0            ; Timer T3B interr. enable
;
.endif
;       Bit definitions HSTCR register
        T9HS        =   7            ; Timer T9 High Speed Enable
        T8HS        =   6            ; Timer T8 High Speed Enable
        T7HS        =   5            ; Timer T7 High Speed Enable
        T6HS        =   4            ; Timer T6 High Speed Enable
        T5HS        =   3            ; Timer T5 High Speed Enable
        T4HS        =   2            ; Timer T4 High Speed Enable
        T3HS        =   1            ; Timer T3 High Speed Enable
        T2HS        =   0            ; Timer T2 High Speed Enable
;
;       Bit definitions TINTA register
        T9INTA      =   7            ; Timer 9 Interrupt A
        T8INTA      =   6            ; Timer 8 Interrupt A
        T7INTA      =   5            ; Timer 7 Interrupt A
        T6INTA      =   4            ; Timer 6 Interrupt A
        T5INTA      =   3            ; Timer 5 Interrupt A
        T4INTA      =   2            ; Timer 4 Interrupt A
        T3INTA      =   1            ; Timer 3 Interrupt A
;
;       Bit definitions TINTB register
        T9INTB      =   7            ; Timer 9 Interrupt B
        T8INTB      =   6            ; Timer 8 Interrupt B
        T7INTB      =   5            ; Timer 7 Interrupt B
        T6INTB      =   4            ; Timer 6 Interrupt B
        T5INTB      =   3            ; Timer 5 Interrupt B
        T4INTB      =   2            ; Timer 4 Interrupt B
        T3INTB      =   1            ; Timer 3 Interrupt B
;
.ifdef _usart
;----- Bit definitions ENU register
        PEN         =   7            ; Parity enable
        PSEL1       =   6            ; Parity select
        PSEL0       =   5            ; Parity select
        XBIT9       =   5            ; 9th transmission bit in 9bit data mode
        CHL1        =   4            ; Select character frame format
        CHL0        =   3            ; Select character frame format
        ERR         =   2            ; Error flag
        RBFL        =   1            ; Received character
        TBMT        =   0            ; Transmited character
;
;----- Bit definitions ENUR register
        DOE         =   7            ; Data overrun error
        FE          =   6            ; Framing error
        PE          =   5            ; Parity error
        BD          =   4            ; Break Detect
        RBIT9       =   3            ; Contains the ninth bit (nine bit frame!)
        ATTN        =   2            ; Attention mode
        XMTG        =   1            ; indicate transmitting mode
        RCVG        =   0            ; indicate framing error
;
;----- Bit definition ENUI register
        STP2        =   7            ; Select number of stop bits
        BRK         =   6            ; Holds TDX low to Generate a BREAK
        ETDX        =   5            ; Select transmit-pin l2
        SSEL        =   4            ; Select UART-mode
        XRCLK       =   3            ; Select clock source for the receiver
        XTCLK       =   2            ; Select clock source for the transmitter
        ERI         =   1            ; Enable interr. from the receiver
        ETI         =   0            ; enable interr. from the transmitter
;
.endif
;       Bit Definitions for ITMR Register
        LSON        =   7            ; Low Speed Oscillator Enable
        HSON        =   6            ; High Speed Oscillator Enable
        DCEN        =   5            ; Dual Clock Enable - Switches T0 To
                                     ;  Low Speed Clock
        CCKSEL      =   4            ; Core Clock Select - Switches Instr
                                     ;  Execution To Low Speed Clock
        ITSEL2      =   2            ; IDLE Timer Period Select bit 2
        ITSEL1      =   1            ; IDLE Timer Period Select bit 1
        ITSEL0      =   0            ; IDLE Timer Period Select bit 0
;
        KEY         =   0x98         ; Required Value for ISP Key

;	Boot ROM labels
	cpgerase    =   0x17         ; page erase
	cmserase    =   0x1A         ; erase all
	creadbf     =   0x11         ; read flash byte
	vblockr     =   0x26         ; read flash block
	cwritebf    =   0x14         ; write flash byte
	vblockw     =   0x23         ; write flash block
	exit        =   0x62         ; device reset
;
; ---------------- End of COP8S3R.INC -----------------------------------
