; -------------------------------------------------------------------
; Common register and bit names for COP8SEC and COP8SER chips

        PORTLD      =   0D0:BYTE     ; Port L data
        PORTLC      =   0D1:BYTE     ; Port L configuration
        PORTLP      =   0D2:BYTE     ; Port L pin
;
        PORTCD      =   0D8:BYTE     ; Port C data
        PORTCC      =   0D9:BYTE     ; Port C configuration
        PORTCP      =   0DA:BYTE     ; Port C pin
;
        PORTGD      =   0D4:BYTE     ; Port G data
        PORTGC      =   0D5:BYTE     ; Port G configuration
        PORTGP      =   0D6:BYTE     ; Port G pin
;
        PORTFD      =   094:BYTE     ; Port F Data
        PORTFC      =   095:BYTE     ; Port F Configuration
        PORTFP      =   096:BYTE     ; Port F input pins (read only)
;
        PORTD       =   0DC:BYTE     ; Port D
;
        SIOR        =   0E9:BYTE     ; SIO shift register
        SIO         =   0E9:BYTE     ; SIO shift register
        S           =   0FF:BYTE     ; Segment register

        TMR1LO      =   0EA:BYTE     ; Timer 1 low byte
        TMR1HI      =   0EB:BYTE     ; Timer 1 high byte
        T1RALO      =   0EC:BYTE     ; Timer 1 RA register low byte
        T1RAHI      =   0ED:BYTE     ; Timer 1 RA register high byte
        T1RBLO      =   0E6:BYTE     ; Timer 1 RB register low byte
        T1RBHI      =   0E7:BYTE     ; Timer 1 RB register high byte
;
        CNTRL       =   0EE:BYTE     ; control register
        PSW         =   0EF:BYTE     ; PSW register
        WDSVR       =   0C7:BYTE     ; Watchdog service register
        WKEDG       =   0C8:BYTE     ; MIWU edge select register
        WKEN        =   0C9:BYTE     ; MIWU enable register
        WKPND       =   0CA:BYTE     ; MIWU pending register
        ICNTRL      =   0E8:BYTE     ; ICNTRL register
        E2CFG       =   0E0:BYTE     ; EERAM Configuration Register
        ITMR        =   0CF:BYTE     ; Selectable IDLE Timer Control
                                     ; Register
;
; CONSTANT DECLARE
;       Alternate function bit definitions on port G
        INTR        =   0            ; Interrupt input
        INT         =   0            ; Interrupt input
        WDOUT       =   1            ; Watchdog output
        T1B         =   2            ; Timer T1B output
        T1A         =   3            ; Timer T1A output
        SO          =   4            ; Serial output
        SK          =   5            ; Serial clock
        SI          =   6            ; Serial input
        CKO         =   7            ; Halt, restart input
;
;       Bit definitions CNTRL register
        T1C3        =   7            ; Timer 1 mode control
        TC1         =   T1C3         ; COP880/840/820 control signal name
        T1C2        =   6            ; Timer 1 mode control
        TC2         =   T1C2         ; COP880/840/820 control signal name
        T1C1        =   5            ; Timer 1 mode control
        TC3         =   T1C1         ; COP880/840/820 control signal name
        T1C0        =   4            ; Start/Stop timer in modes 1 and 2
                                     ; Underflow interrupt pending in mode 3
        TRUN        =   T1C0         ; COP880/840/820 control signal name
        MSEL        =   3            ; Enable Microwire
        IEDG        =   2            ; Selects external interr. edge polarity
        S1          =   1            ; Microwire clock divide select
        SL1         =   S1           ; Microwire clock divide select
        S0          =   0            ; Microwire clock divide select
        SL0         =   S0           ; Microwire clock divide select
;
;       Bit definitions PSW register
        HC          =   7            ; Half carry flag
        C           =   6            ; Carry flag
        TPND        =   5            ; Timer interr. pending
        T1PNDA      =   TPND         ; Timer interr. pending
        ENTI        =   4            ; Timer interr. enable
        T1ENA       = ENTI           ; Timer interr. enable
        IPND        =   3            ; External interr. pending
        EXPND       = IPND           ; External interr. pending
        BUSY        =   2            ; Microwire busy shifting
        ENI         =   1            ; External interr. enable
        EXEN        = ENI            ; External interr. enable
        GIE         =   0            ; Global interr. enable
;
;       Bit definitions ICNTRL register
        FLAG1       =   7
        LPEN        =   6            ; L-Port interr. enable
        FLAG2       = LPEN           ; L-Port interr. enable
        T0PND       =   5            ; Timer T0 interr. pending
        PPND        =   T0PND        ; Timer T0 interr. pending
        T0EN        =   4            ; Timer T0 interr. enable
        PEN         =   T0EN         ; Timer T0 interr. enable
        WPND        =   3            ; Microwire interr. pending
        uWPND       =   WPND         ; Microwire interr. pending
        WEN         =   2            ; Microwire interr. enable
        uWEN        =   WEN          ; Microwire interr. enable
        T1PNDB      =   1            ; Timer T1B interr. pending flag
        T1ENB       =   0            ; Timer T1B interr. enable
;
;       Bit definitions E2CFG register
        E2EI        =   0            ; EERAM Interrupt Enable
        E2BUSY      =   1            ; EERAM Busy Bit
        E2ILRW      =   2            ; EERAM Illegal Read or Write
        E2PEND      =   3            ; EERAM Interrupt pending
;
;       Bit Definitions for ITMR Register
        ITSEL2      =   2            ; IDLE Timer Period Select bit 2
        ITSEL1      =   1            ; IDLE Timer Period Select bit 1
        ITSEL0      =   0            ; IDLE Timer Period Select bit 0
