; This is cop8taa.inc
;
; Revision History
; 16/10/02 fixed PORTC MIWU register definitions
; 16/10/02 fixed PORTJC definition
; 01/10/02 added definition for LWKEN
; 26/09/02 changed GCMEM to GCMEN

; Predeclare I/O and control registers frequently used by COP8 programmer.

        .incld cop8.inc

        COPCHIP = COP8TAA               ; Chip Definition

        .macro  setopt
        .mloc   sec,cki,wd,halt,flex

		.ifb @1			; if null
			sec = 0 	; default value (not secure)
		.else
			sec = @1
		.endif

		.ifb @2			; if null
			cki = 0 	; default value (external clock)
		.else
			cki = @2
		.endif


		.ifb @3      		; if null
			wd = 0  	; default value (Watchdog enabled)
		.else
			wd = @2
		.endif

		.ifb @4			; if null
			halt = 0	; default value (HALT enabled)
		.else
			halt = @3
		.endif

		.ifb @5			; if null
			flex = 1	; default value (Execute from Flash)
		.else
			flex = @4
		.endif

        .sect   OPTION, CONF
		CONFIG:	.db ((((((cki / 4) or sec) shl 2 or (cki mod 4)) shl 1 or wd) shl 1 or halt) shl 1 or flex)
	.endsect

        .endm

;
        CWKEDG      =   0x84:BYTE    ; Port C MIWU edge select register
        CWKEN       =   0x85:BYTE    ; Port C MIWU enable register
        CWKPND      =   0x86:BYTE    ; Port C MIWU pending register
;
        PORTFD      =   0x94:BYTE    ; Port F Data
        PORTFC      =   0x95:BYTE    ; Port F Configuration
        PORTFP      =   0x96:BYTE    ; Port F input pins (read only)
;
        ISPADLO     =   0xA8:BYTE    ; ISP Address Register Low Byte
        ISPADHI     =   0xA9:BYTE    ; ISP Address Register High Byte
        ISPRD       =   0xAA:BYTE    ; ISP Read Data Register
        ISPWR       =   0xAB:BYTE    ; ISP Write Data Register
;
        ACBSDA      =   0xB8:BYTE    ; ACB serial data register
        ACBST       =   0xB9:BYTE    ; ABC status register
        ACBCST      =   0xBA:BYTE    ; ABC control and status
        ACBCTL1     =   0xBB:BYTE    ; ABC control register 1
        ACBADDR     =   0xBC:BYTE    ; ACB own address register
        ACBCTL2     =   0xBD:BYTE    ; ABC control register 2
;
        WDSVR       =   0xC7:BYTE    ; Watch dog service register
        WKEDG       =   0xC8:BYTE    ; MIWU edge select register
        LWKEDG      =   0xC8:BYTE    ; MIWU edge select register
        WKEN        =   0xC9:BYTE    ; MIWU enable register
        LWKEN       =   0xC9:BYTE    ; MIWU enable register
        WKPND       =   0xCA:BYTE    ; MIWU pending register
        LWKPND      =   0xCA:BYTE    ; MIWU pending register
;
        ITMR        =   0xCF:BYTE    ; Idle Timer Control Register
;
        PORTLD      =   0xD0:BYTE    ; Port L data
        PORTLC      =   0xD1:BYTE    ; Port L configuration
        PORTLP      =   0xD2:BYTE    ; Port L pin
;
        PORTGD      =   0xD4:BYTE    ; Port G data
        PORTGC      =   0xD5:BYTE    ; Port G configuration
        PORTGP      =   0xD6:BYTE    ; Port G pin
;
        PORTCD      =   0xD8:BYTE    ; Port C data
        PORTCC      =   0xD9:BYTE    ; Port C configuration
        PORTCP      =   0xDA:BYTE    ; Port C pin
;
        PORTJD      =   0xDC:BYTE    ; Port J data
        PORTJC      =   0xDD:BYTE    ; Port J configuration
        PORTJP      =   0xDE:BYTE    ; Port J pin
;
	CLKPSC      =   0xDF:BYTE    ; Oscillator Prescale
;
        PGMTIM      =   0xE1:BYTE    ; E2 and Flash Write Timing Register
        ISPKEY      =   0xE2:BYTE    ; ISP Key Register
;
        T1RBLO      =   0xE6:BYTE    ; Timer 1 RB register low byte
        T1RBHI      =   0xE7:BYTE    ; Timer 1 RB register high byte
;
        ICNTRL      =   0xE8:BYTE    ; Interrupt control register
;
        SIOR        =   0xE9:BYTE    ; Serial I/O shift register
        SIO         =   0xE9:BYTE    ; Serial I/O shift register
;
        TMR1LO      =   0xEA:BYTE    ; Timer 1 low byte
        TMR1HI      =   0xEB:BYTE    ; Timer 1 high byte
        T1RALO      =   0xEC:BYTE    ; Timer 1 RA register low byte
        T1RAHI      =   0xED:BYTE    ; Timer 1 RA register high byte
;
        CNTRL       =   0xEE:BYTE    ; control register
        PSW         =   0xEF:BYTE    ; PSW register
;
        BYTECOUNTLO =   0xF1:BYTE    ; When JSRB Boot Rom used
;
        .CHIP 8TAA      ; specifies max. ROM address 3FF
                        ; RAM = 128

;------------------------------------------------------------------------
; Bit Constant Declarations.
;
;----- Alternate function bit definitions on port G

        INT         =   0            ; Interrupt input
        INTR        =   0            ; Interrupt input
        WDOUT       =   1            ; Watchdog output
        T1B         =   2            ; Timer T1B output
        T1A         =   3            ; Timer T1A output
        SO          =   4            ; Serial output
        SK          =   5            ; Serial clock
        SI          =   6            ; Serial input
        CKO         =   7            ; Halt, restart input
;
;----- Alternate function bit definitions on port L
        SDA         =   0            ; microwire serial data
        SCL         =   1            ; microwire serial clock
;
;----- Bit definitions CNTRL register
        T1C3        =   7            ; Timer 1 mode control
        TC1         =   T1C3         ; COP880/840/820 control signal name
        T1C2        =   6            ; Timer 1 mode control
        TC2         =   T1C2         ; COP880/840/820 control signal name
        T1C1        =   5            ; Timer 1 mode control
        TC3         =   T1C1         ; COP880/840/820 control signal name
        T1C0        =   4            ; Start/Stop timer in modes 1 and 2
                                     ; Underflow interrupt pending in mode 3
        TRUN        =   T1C0         ; COP880/840/820 control signal name
        MSEL        =   3            ; Enable Microwire
        IEDG        =   2            ; Selects external interr. edge polarity
        SL1         =   1            ; Microwire clock divide select
        SL0         =   0            ; Microwire clock divide select
;
;----- Bit definitions PSW register
        HC          =   7            ; Half Historical Redundant carry flag
        C           =   6            ; Carry flag
        T1PNDA      =   5            ; Timer T1A interrupt pending
        TPND        =   T1PNDA       ; Historical Redundant
        T1ENA       =   4            ; Timer T1A interrupt enable
        ENTI        =   T1ENA        ; Historical Redundant
        EXPND       =   3            ; External interrupt pending
        IPND        =   EXPND        ; Historical Redundant
        BUSY        =   2            ; Microwire busy shifting
        EXEN        =   1            ; External interurpt enable
        ENI         =   EXEN         ; Historical Redundant
        GIE         =   0            ; Global interr. enable
;
;----- Bit definitions ICNTRL register
        FLAG1       =   7
        LPEN        =   6            ; L-Port interr. enable
        FLAG2       =   6            ; L-Port interr. enable
        T0PND       =   5            ; Timer T0 interr. pending
        PND         =   5            ; Timer T0 interr. pending
        T0EN        =   4            ; Timer T0 interr. enable
        WPND        =   3            ; Microwire interr. pending
        uWPND       =   3            ; Microwire interr. pending
        WEN         =   2            ; Microwire interr. enable
        T1PNDB      =   1            ; Timer T1B interr. pending flag
        T1ENB       =   0            ; Timer T1B interr. enable
;
;	Bit Definitions for ACBST Register
	SLVSTP	    =   7            ; Slave Stop Bit
	SDAST	    =   6            ; SDA Status
	BER	    =   5            ; Bus Error
	NEGACK	    =   4            ; Negative Acknowledge
	NMATCH	    =   2            ; New Match
	MASTER	    =   1            ; Master/Slave
	XMIT	    =   0            ; Direction
;
;	Bit Definitions for ACBCST Register
	TGSCL	    =   5            ; Toggle SCL
	TSDA	    =   4            ; Test SDA
	GCMTCH	    =   3            ; Global Call Match
	MATCH	    =   2            ; Address Match
	BB	    =   1            ; Bus Busy
	ACBUSY	    =   0            ; ACB Module Busy
;
;	Bit Definitions for ACBCTL1 Register
	CLRST	    =   7            ; Clear Status
	NMINTE	    =   6            ; New Match Interrupt Enable
	GCMEN	    =   5            ; Global Call Match Enable
	ACK	    =   4            ; Acknowledge
	INTEN	    =   2            ; Interrupt Enable
	STOP	    =   1            ; Stop/Abort Operation
	START	    =   0            ; Start ACCESS.Bus
;
;	Bit Definitions for ACBADDR Register
	SAEN	    =   7            ; Slave Address Enable
;
;	Bit Definitions for ACBCTL2 Register
	ENABLE	    =   0            ; ACCESS.Bus Module Enable
;
;	Bit Definitions for ITMR Register
	ITSEL2	    =   2            ; IDLE Timer Period Select bit 2
	ITSEL1	    =   1            ; IDLE Timer Period Select bit 1
	ITSEL0	    =   0            ; IDLE Timer Period Select bit 0
;
        KEY         =   0x98         ; Required Value for ISP Key

;	Boot ROM labels
	cpgerase    =   0x17         ; page erase
	cmserase    =   0x1A         ; erase all
	creadbf     =   0x11         ; read flash byte
	vblockr     =   0x26         ; read flash block
	cwritebf    =   0x14         ; write flash byte
	vblockw     =   0x23         ; write flash block
	exit        =   0x62         ; device reset
;
; ---------------- End of COP8TAA.INC -----------------------------------
